@@ -2,15 +2,19 @@ import requests
 import json
 
 
+def make_header(token, org_id):
+    return {
+        "orgId": org_id,
+        "Authorization": f"Zoho-oauthtoken {token.access}"
+    }
+
+
 def get_ticket(token, org_id, ticket_id, **kwargs):
     url = 'https://desk.zoho.com/api/v1/tickets/{}'.format(ticket_id)
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     response = requests.get(url=url, headers=headers, params=kwargs)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return get_ticket(token, org_id, ticket_id, **kwargs)
@@ -22,13 +26,10 @@ def get_ticket(token, org_id, ticket_id, **kwargs):
 
 def get_tickets(token, org_id, **kwargs):
     url = 'https://desk.zoho.com/api/v1/tickets'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     response = requests.get(url=url, headers=headers, params=kwargs)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return get_tickets(token, org_id, **kwargs)
@@ -40,15 +41,12 @@ def get_tickets(token, org_id, **kwargs):
 
 def create_ticket(token, org_id, data_object):
     url = 'https://desk.zoho.com/api/v1/tickets'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
 
     data = json.dumps(data_object).encode("utf-8")
     response = requests.post(url=url, headers=headers, data=data)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return create_ticket(token, org_id, data_object)
@@ -57,12 +55,9 @@ def create_ticket(token, org_id, data_object):
 def update_ticket(token, org_id, ticket_id, data_object):
     url = f'https://desk.zoho.com/api/v1/tickets/{ticket_id}'
     data = json.dumps(data_object).encode('utf-8')
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     response = requests.patch(url=url, headers=headers, data=data)
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return update_ticket(token, org_id, ticket_id, data_object)
@@ -74,10 +69,7 @@ def update_ticket(token, org_id, ticket_id, data_object):
 
 def trash_ticket(token, org_id, ticket_id_list):
     url = 'https://desk.zoho.com/api/v1/tickets/moveToTrash'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     
     data_object = {'ticketIds': ticket_id_list}
 
@@ -85,7 +77,7 @@ def trash_ticket(token, org_id, ticket_id_list):
 
     response = requests.post(url=url, headers=headers, data=data)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return trash_ticket(token, org_id, ticket_id_list)
@@ -96,17 +88,14 @@ def trash_ticket(token, org_id, ticket_id_list):
 
 def move_ticket(token, org_id, ticket_id, department_id):
     url = f'https://desk.zoho.com/api/v1/tickets/{ticket_id}/move'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     data_object = {'departmentId': department_id}
 
     data = json.dumps(data_object).encode('utf-8')
 
     response = requests.post(url=url, headers=headers, data=data)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return move_ticket(token, org_id, ticket_id, department_id)
@@ -117,13 +106,10 @@ def move_ticket(token, org_id, ticket_id, department_id):
 
 def mark_read(token, org_id, ticket_id):
     url = f'https://desk.zoho.com/api/v1/tickets/{ticket_id}/markAsRead'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     response = requests.post(url=url, headers=headers)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return mark_read(token, org_id, ticket_id)
@@ -134,13 +120,10 @@ def mark_read(token, org_id, ticket_id):
 
 def mark_unread(token, org_id, ticket_id):
     url = f'https://desk.zoho.com/api/v1/tickets/{ticket_id}/markAsUnRead'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     response = requests.post(url=url, headers=headers)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return mark_unread(token, org_id, ticket_id)
@@ -151,14 +134,11 @@ def mark_unread(token, org_id, ticket_id):
 
 def ticket_history(token, org_id, ticket_id, **kwargs):
     url = f'https://desk.zoho.com/api/v1/tickets/{ticket_id}/History'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     
     response = requests.get(url=url, headers=headers, params=kwargs)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return ticket_history(token, org_id, ticket_id, **kwargs)
@@ -170,13 +150,10 @@ def ticket_history(token, org_id, ticket_id, **kwargs):
 
 def ticket_resolution(token, org_id, ticket_id):
     url = f'https://desk.zoho.com/api/v1/tickets/{ticket_id}/resolution'
-    headers = {
-        'orgId': org_id,
-        'Authorization': 'Zoho-oauthtoken {}'.format(token.access)
-    }
+    headers = make_header(token, org_id)
     response = requests.get(url=url, headers=headers)
 
-    if response.status_code == 400:
+    if response.status_code == 401:
         print("Auth")
         token.generate()
         return ticket_resolution(token, org_id, ticket_id)
